Bibliography
============

This is a collection of various bibliographic items referenced in the
documentation.

.. [Case2013] Case, Roland. "The Unfortuate Consequences of Bloom's Taxonomy." Social Education 77.4 (2013): 196-200.
.. [Cheang2003] Cheang, Brenda, et al. "Automated grading of programming assignments." Proceedings of the 11th International Conference on Computers in Education (ICCE 2003). 2003.
.. [Losada2010] Losada, Isidoro Hernin, Cristóbal Pareja Flores, and J. Éngel Velizquez Iturbide. "Pedagogical use of automatic graders." Advances in Learning Processes, InTech (2010).
.. [Saikkonen2001] Saikkonen, Riku, Lauri Malmi, and Ari Korhonen. "Fully automatic assessment of programming exercises." Proceedings of the 6th annual conference on Innovation and technology in computer science education. 2001.
.. [Schinke2014] Schinske, Jeffrey, and Kimberly Tanner. "Teaching more by grading less (or differently)." CBE—Life Sciences Education 13.2 (2014): 159-166.
.. [Wilcox2015] Wilcox, Chris. "The role of automation in undergraduate computer science education." Proceedings of the 46th ACM Technical Symposium on Computer Science Education. 2015.
.. [Wilcox2016] Wilcox, Chris. "Testing strategies for the automated grading of student programs." Proceedings of the 47th ACM Technical Symposium on Computing Science Education. 2016.
